---------------------------------------------------------------------
-- ***************************************************************
-- Licensed Materials - Property of IBM
-- 5724-V09
--   
-- Copyright IBM Corp. 2009 All Rights Reserved
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp
-- ***************************************************************
-- NAME
--    krzgrant.sql
-- FUNCTION
--    Grant access to all views used by Tivoli Monitoring Agent.
-- NOTES
--    This file must be run while logged-in as SYSDBA.
--    Catalog.sql must have been run before this file is run.
--
--------------------------------------------------------------------------
-- Usage Instructions
-- Change directory to where this file is
--    cd <directory path name of this file>
-- Bringup sqlplus 
--    sqlplus
--    login : sys
--    password : <enter  password for user SYS>
-- Create the user ID using the following command
--    create user <user ID> identified by <password>
--    where <user ID> is the user ID that the Oracle Monitoring Agent will use
--          <password> is the desired password for the user ID
--    For example: create user tivoli identified by password;
-- Run this script
--    @krzgrant.sql <user ID> <temporary directory>
--
-- (1)         <user ID>         = ID of the Oracle user.  Must be created 
--                                 prior to running this sql file.
--
--                                 Example value: tivoli
--
-- (2)         <temporary dir>   = Name of the temporary directory where sql
--                                 will output the log to the file krzagent.log.
--                                 Must be created prior to running this sql
--                                 file.
--
--                                 Example value: /opt/IBM/ITM/tmp
--
--------------------------------------------------------------------------

set echo on;
set serveroutput on;
spool &2/krzgrant.log
declare
	version integer;
	userName varchar(20);
	isExist integer;
begin

  userName:='&1';  
  isExist:=0;
  
  select count(username) 
  into   isExist 
  from   dba_users where username=upper('&1');
  
  if isExist = 0  then
      dbms_output.put_line('The user '||userName||' does not exist, please create it first!');
      return;
  end if;
  
  execute immediate 'alter session set NLS_NUMERIC_CHARACTERS=''.,'''; 
  
  select to_number(substr(banner,instr(banner,'Release')+8,instr(banner,'.',1,2)-8-instr(banner,'Release')))*10
	into   version
	from   V$VERSION
	where  banner like 'Oracle%' and rownum < 2;
	
	if version >=112 then
		execute immediate 'grant select on GV_$ASM_DISKGROUP_STAT to '||userName;
		execute immediate 'grant select on GV_$ASM_DISK_STAT to '||userName;
		execute immediate 'grant select on GV_$CLUSTER_INTERCONNECTS to '||userName;
		execute immediate 'grant select on GV_$FLASHBACK_DATABASE_LOGFILE to '||userName;
		execute immediate 'grant select on V_$DATAGUARD_STATS to '||userName;
		execute immediate 'grant select on V_$FLASH_RECOVERY_AREA_USAGE to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_PROCESS to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_PROGRESS to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_STATE to '||userName;
	elsif version =111 then
		execute immediate 'grant select on GV_$ASM_DISKGROUP_STAT to '||userName;
		execute immediate 'grant select on GV_$ASM_DISK_STAT to '||userName;
		execute immediate 'grant select on GV_$CLUSTER_INTERCONNECTS to '||userName;
		execute immediate 'grant select on GV_$FLASHBACK_DATABASE_LOGFILE to '||userName;
		execute immediate 'grant select on V_$DATAGUARD_STATS to '||userName;
		execute immediate 'grant select on V_$FLASH_RECOVERY_AREA_USAGE to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_PROCESS to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_PROGRESS to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_STATE to '||userName;
	elsif version =102 then
		execute immediate 'grant select on GV_$ASM_DISKGROUP_STAT to '||userName;
		execute immediate 'grant select on GV_$ASM_DISK_STAT to '||userName;
		execute immediate 'grant select on GV_$CLUSTER_INTERCONNECTS to '||userName;
		execute immediate 'grant select on V_$DATAGUARD_STATS to '||userName;
		execute immediate 'grant select on V_$FLASH_RECOVERY_AREA_USAGE to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_PROCESS to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_PROGRESS to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY_STATE to '||userName;
	elsif version =101 then
		execute immediate 'grant select on DBA_LOGSTDBY_PROGRESS to '||userName;
		execute immediate 'grant select on GV_$ASM_DISK to '||userName;
		execute immediate 'grant select on GV_$ASM_DISKGROUP to '||userName;
		execute immediate 'grant select on V_$LOGSTDBY to '||userName;
	else
		dbms_output.put_line('It is an unsupported version!');
		return;
	end if;

	---------------------------------------------
	-- Grant common objects 
	---------------------------------------------

	execute immediate 'grant select on DBA_CLUSTERS to '||userName;
	execute immediate 'grant select on DBA_DATA_FILES to '||userName;
	execute immediate 'grant select on DBA_EXTENTS to '||userName;
	execute immediate 'grant select on DBA_FREE_SPACE to '||userName;
	execute immediate 'grant select on DBA_HIST_SNAPSHOT to '||userName;
	execute immediate 'grant select on DBA_HIST_SQLSTAT to '||userName;
	execute immediate 'grant select on DBA_HIST_SQLTEXT to '||userName;
	execute immediate 'grant select on DBA_HIST_SQL_PLAN to '||userName;
	execute immediate 'grant select on DBA_HIST_SYSMETRIC_SUMMARY to '||userName;
	execute immediate 'grant select on DBA_INDEXES to '||userName;
	execute immediate 'grant select on DBA_OBJECTS to '||userName;
	execute immediate 'grant select on DBA_SEGMENTS to '||userName;
	execute immediate 'grant select on DBA_TABLES to '||userName;
	execute immediate 'grant select on DBA_TABLESPACES to '||userName;
	execute immediate 'grant select on DBA_TEMP_FILES to '||userName;
	execute immediate 'grant select on DBA_UNDO_EXTENTS to '||userName;
	execute immediate 'grant select on GV_$ARCHIVE_DEST to '||userName;
	execute immediate 'grant select on GV_$ARCHIVE_DEST_STATUS to '||userName;
	execute immediate 'grant select on GV_$ASM_CLIENT to '||userName;
	execute immediate 'grant select on GV_$ASM_TEMPLATE to '||userName;
	execute immediate 'grant select on GV_$BGPROCESS to '||userName;
	execute immediate 'grant select on GV_$BUFFER_POOL_STATISTICS to '||userName;
	execute immediate 'grant select on GV_$DATAFILE_HEADER to '||userName;
	execute immediate 'grant select on GV_$DLM_MISC to '||userName;
	execute immediate 'grant select on GV_$ENQUEUE_STAT to '||userName;
	execute immediate 'grant select on GV_$FILEMETRIC to '||userName;
	execute immediate 'grant select on GV_$FILESTAT to '||userName;
	execute immediate 'grant select on GV_$FLASHBACK_DATABASE_LOG to '||userName;
	execute immediate 'grant select on GV_$GES_BLOCKING_ENQUEUE to '||userName;
	execute immediate 'grant select on GV_$INSTANCE to '||userName;
	execute immediate 'grant select on GV_$LATCH to '||userName;
	execute immediate 'grant select on GV_$LATCH_CHILDREN to '||userName;
	execute immediate 'grant select on GV_$LIBRARYCACHE to '||userName;
	execute immediate 'grant select on GV_$LOCK to '||userName;
	execute immediate 'grant select on GV_$LOCKED_OBJECT to '||userName;
	execute immediate 'grant select on GV_$LOG to '||userName;
	execute immediate 'grant select on GV_$OPTION to '||userName;
	execute immediate 'grant select on GV_$OSSTAT to '||userName;
	execute immediate 'grant select on GV_$PARAMETER to '||userName;
	execute immediate 'grant select on GV_$PGASTAT to '||userName;
	execute immediate 'grant select on GV_$PGA_TARGET_ADVICE to '||userName;
	execute immediate 'grant select on GV_$PROCESS to '||userName;
	execute immediate 'grant select on GV_$RESOURCE_LIMIT to '||userName;
	execute immediate 'grant select on GV_$ROLLSTAT to '||userName;
	execute immediate 'grant select on GV_$ROWCACHE to '||userName;
	execute immediate 'grant select on GV_$SEGMENT_STATISTICS to '||userName;
	execute immediate 'grant select on GV_$SERVICES to '||userName;
	execute immediate 'grant select on GV_$SESSION to '||userName;
	execute immediate 'grant select on GV_$SESSION_WAIT to '||userName;
	execute immediate 'grant select on GV_$SESS_IO to '||userName;
	execute immediate 'grant select on GV_$SGA to '||userName;
	execute immediate 'grant select on GV_$SGAINFO to '||userName;
	execute immediate 'grant select on GV_$SGASTAT to '||userName;
	execute immediate 'grant select on GV_$SORT_SEGMENT to '||userName;
	execute immediate 'grant select on GV_$SQL to '||userName;
	execute immediate 'grant select on GV_$SYSMETRIC to '||userName;
	execute immediate 'grant select on GV_$SYSMETRIC_HISTORY to '||userName;
	execute immediate 'grant select on GV_$SYSMETRIC_SUMMARY to '||userName;
	execute immediate 'grant select on GV_$SYSSTAT to '||userName;
	execute immediate 'grant select on GV_$SYSTEM_PARAMETER to '||userName;
	execute immediate 'grant select on GV_$UNDOSTAT to '||userName;
	execute immediate 'grant select on SYS.OBJ$ to '||userName;
	execute immediate 'grant select on SYS.TS$ to '||userName;
	execute immediate 'grant select on SYS.UNDO$ to '||userName;
	execute immediate 'grant select on V_$ACTIVE_INSTANCES to '||userName;
	execute immediate 'grant select on V_$ARCHIVED_LOG to '||userName;
	execute immediate 'grant select on V_$ARCHIVE_DEST to '||userName;
	execute immediate 'grant select on V_$ARCHIVE_DEST_STATUS to '||userName;
	execute immediate 'grant select on V_$ARCHIVE_GAP to '||userName;
	execute immediate 'grant select on V_$BGPROCESS to '||userName;
	execute immediate 'grant select on V_$DATABASE to '||userName;
	execute immediate 'grant select on V_$DATAFILE to '||userName;
	execute immediate 'grant select on V_$DATAFILE_HEADER to '||userName;
	execute immediate 'grant select on V_$DATAGUARD_STATUS to '||userName;
	execute immediate 'grant select on V_$INSTANCE to '||userName;
	execute immediate 'grant select on V_$LOCK_TYPE to '||userName;
	execute immediate 'grant select on V_$LOG to '||userName;
	execute immediate 'grant select on V_$LOGFILE to '||userName;
	execute immediate 'grant select on V_$LOGSTDBY_STATS to '||userName;
	execute immediate 'grant select on V_$LOG_HISTORY to '||userName;
	execute immediate 'grant select on V_$MANAGED_STANDBY to '||userName;
	execute immediate 'grant select on V_$PARAMETER to '||userName;
	execute immediate 'grant select on V_$RECOVERY_FILE_DEST to '||userName;
	execute immediate 'grant select on V_$RECOVERY_PROGRESS to '||userName;
	execute immediate 'grant select on V_$SPPARAMETER to '||userName;
	execute immediate 'grant select on V_$STANDBY_LOG to '||userName;
	execute immediate 'grant select on V_$TABLESPACE to '||userName;
	execute immediate 'grant select on V_$TEMPFILE to '||userName;
	execute immediate 'grant select on V_$VERSION to '||userName;

	------------------------------------------------
	-- Grant create session to the user
	------------------------------------------------
	execute immediate 'grant connect               to '||userName;
	execute immediate 'grant create session        to '||userName;

	------------------------------------------------
end;
/
spool off
set echo off;
------------------------------------------------
